@@ -8,7 +8,7 @@
    or visit http://www.gnu.org/copyleft/gpl.html
 
    \file
-   \version $Id: chapters.cpp 2848 2005-03-06 21:43:33Z mosu $
+   \version $Id: chapters.cpp 2872 2005-04-07 08:46:58Z mosu $
 
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
 */
@@ -457,18 +457,43 @@ parse_chapters(mm_text_io_c *in,
    Its parameters don't have to be checked for validity.
 
    \param atom The atom for which the start timecode should be returned.
+   \param value_if_not_found The value to return if no start timecode child
+     element was found. Defaults to -1.
 
-   \return The start timecode or \c -1 if the atom doesn't contain such a
-     child element.
+   \return The start timecode or \c value_if_not_found if the atom doesn't
+     contain such a child element.
 */
 int64_t
-get_chapter_start(KaxChapterAtom &atom) {
+get_chapter_start(KaxChapterAtom &atom,
+                  int64_t value_if_not_found) {
   KaxChapterTimeStart *start;
 
   start = FINDFIRST(&atom, KaxChapterTimeStart);
-  if (start == NULL)
-    return -1;
-  return uint64(*static_cast<EbmlUInteger *>(start));
+  if (NULL == start)
+    return value_if_not_found;
+  return uint64(*start);
+}
+
+/** \brief Get the end timecode for a chapter atom.
+
+   Its parameters don't have to be checked for validity.
+
+   \param atom The atom for which the end timecode should be returned.
+   \param value_if_not_found The value to return if no end timecode child
+     element was found. Defaults to -1.
+
+   \return The start timecode or \c value_if_not_found if the atom doesn't
+     contain such a child element.
+*/
+int64_t
+get_chapter_end(KaxChapterAtom &atom,
+                int64_t value_if_not_found) {
+  KaxChapterTimeEnd *end;
+
+  end = FINDFIRST(&atom, KaxChapterTimeEnd);
+  if (NULL == end)
+    return value_if_not_found;
+  return uint64(*end);
 }
 
 /** \brief Get the name for a chapter atom.
@@ -593,6 +618,9 @@ fix_mandatory_chapter_elements(EbmlElement *e) {
    given with <tt>[min_tc..max_tc]</tt> are deleted. This is the workhorse
    for ::select_chapters_in_timeframe
 
+   Chapters which start before the window but end inside or after the window
+   are kept as well, and their start timecode is adjusted.
+
    Its parameters don't have to be checked for validity.
 
    \param min_tc The minimum timecode to accept.
@@ -607,62 +635,221 @@ remove_entries(int64_t min_tc,
                int64_t max_tc,
                int64_t offset,
                EbmlMaster &m) {
-  int i;
-  bool remove;
+  struct chapter_entry_t {
+    bool remove, spans, is_atom;
+    int64_t start, end;
+
+    chapter_entry_t():
+      remove(false), spans(false), is_atom(false), start(0), end(-1) {}
+  } *entries;
+
+  int i, last_atom_at;
   KaxChapterAtom *atom;
   KaxChapterTimeStart *cts;
   KaxChapterTimeEnd *cte;
   EbmlMaster *m2;
-  int64_t start_tc, end_tc;
 
-  i = 0;
-  while (i < m.ListSize()) {
+  if (0 == m.ListSize())
+    return;
+
+  entries = new chapter_entry_t[m.ListSize()];
+  last_atom_at = -1;
+
+  // Determine whether or not an entry has to be removed. Also retrieve
+  // the start and end timecodes.
+  for (i = 0; m.ListSize() > i; ++i) {
     atom = dynamic_cast<KaxChapterAtom *>(m[i]);
-    if (atom != NULL) {
-      cts = static_cast<KaxChapterTimeStart *>
-        (atom->FindFirstElt(KaxChapterTimeStart::ClassInfos, false));
+    if (NULL == atom)
+      continue;
 
-      remove = false;
+    last_atom_at = i;
+    entries[i].is_atom = true;
 
-      start_tc = uint64(*static_cast<EbmlUInteger *>(cts));
-      if (start_tc < min_tc)
-        remove = true;
-      else if ((max_tc >= 0) && (start_tc > max_tc))
-        remove = true;
+    cts = static_cast<KaxChapterTimeStart *>
+      (atom->FindFirstElt(KaxChapterTimeStart::ClassInfos, false));
 
-      if (remove) {
-        m.Remove(i);
-        delete atom;
-      } else
-        i++;
+    if (NULL != cts)
+      entries[i].start = uint64(*static_cast<EbmlUInteger *>(cts));
 
-    } else
-      i++;
+    cte = static_cast<KaxChapterTimeEnd *>
+      (atom->FindFirstElt(KaxChapterTimeEnd::ClassInfos, false));
+
+    if (NULL != cte)
+      entries[i].end = uint64(*static_cast<EbmlUInteger *>(cte));
   }
 
-  for (i = 0; i < m.ListSize(); i++) {
-    atom = dynamic_cast<KaxChapterAtom *>(m[i]);
-    if (atom != NULL) {
-      cts = static_cast<KaxChapterTimeStart *>
-        (atom->FindFirstElt(KaxChapterTimeStart::ClassInfos, false));
-      cte = static_cast<KaxChapterTimeEnd *>
-        (atom->FindFirstElt(KaxChapterTimeEnd::ClassInfos, false));
+  // We can return if we don't have a single atom to work with.
+  if (-1 == last_atom_at)
+    return;
 
-      *static_cast<EbmlUInteger *>(cts) =
-        uint64(*static_cast<EbmlUInteger *>(cts)) - offset;
-      if (cte != NULL) {
-        end_tc =  uint64(*static_cast<EbmlUInteger *>(cte));
-        if ((max_tc >= 0) && (end_tc > max_tc))
-          end_tc = max_tc;
-        end_tc -= offset;
-        *static_cast<EbmlUInteger *>(cte) = end_tc;
+  for (i = 0; m.ListSize() > i; ++i) {
+    atom = dynamic_cast<KaxChapterAtom *>(m[i]);
+    if (NULL == atom)
+      continue;
+
+    // Calculate the end timestamps and determine whether or not an entry spans
+    // several segments.
+    if (-1 == entries[i].end) {
+      if (i == last_atom_at)
+        entries[i].end = 1LL << 62;
+
+      else {
+        int next_atom = i + 1;
+
+        while (!entries[next_atom].is_atom)
+          ++next_atom;
+
+        entries[i].end = entries[next_atom].start;
       }
     }
 
+    if ((entries[i].start < min_tc)
+        ||
+        ((max_tc >= 0) && (entries[i].start > max_tc)))
+      entries[i].remove = true;
+
+    if (entries[i].remove && (entries[i].start < min_tc) &&
+        (entries[i].end > min_tc))
+      entries[i].spans = true;
+
+    mxverb(3, "remove_chapters: entries[%d]: remove %d spans %d start %lld "
+           "end %lld\n", i, entries[i].remove, entries[i].spans,
+           entries[i].start, entries[i].end);
+
+    // Spanning entries must be kept, and their start timecode must be
+    // adjusted. Entries that are to be deleted will be deleted later and
+    // have to be skipped for now.
+    if (entries[i].remove && !entries[i].spans)
+      continue;
+
+    cts = static_cast<KaxChapterTimeStart *>
+      (atom->FindFirstElt(KaxChapterTimeStart::ClassInfos, false));
+    cte = static_cast<KaxChapterTimeEnd *>
+      (atom->FindFirstElt(KaxChapterTimeEnd::ClassInfos, false));
+
+    if (entries[i].spans)
+      *static_cast<EbmlUInteger *>(cts) = min_tc;
+
+    *static_cast<EbmlUInteger *>(cts) =
+      uint64(*static_cast<EbmlUInteger *>(cts)) - offset;
+    if (NULL != cte) {
+      int64_t end_tc =  uint64(*static_cast<EbmlUInteger *>(cte));
+      if ((max_tc >= 0) && (end_tc > max_tc))
+        end_tc = max_tc;
+      end_tc -= offset;
+      *static_cast<EbmlUInteger *>(cte) = end_tc;
+    }
+
     m2 = dynamic_cast<EbmlMaster *>(m[i]);
     if (m2 != NULL)
       remove_entries(min_tc, max_tc, offset, *m2);
   }
+
+  // Now really delete those entries.
+  for (i = m.ListSize() - 1; 0 <= i; --i)
+    if (entries[i].remove && !entries[i].spans) {
+      delete m[i];
+      m.Remove(i);
+    }
+
+  delete []entries;
+}
+
+/** \brief Merge all chapter atoms sharing the same UID
+
+   If two or more chapters with the same UID are encountered on the same
+   level then those are merged into a single chapter. The start timecode
+   is the minimum start timecode of all the chapters, and the end timecode
+   is the maximum end timecode of all the chapters.
+
+   The parameters do not have to be checked for validity.
+
+   \param master The master containing the elements to check.
+*/
+void
+merge_chapter_entries(EbmlMaster &master) {
+  int i, k;
+
+  // Iterate over all children of the atomaster.
+  for (i = 0; master.ListSize() > i; ++i) {
+    KaxChapterAtom *atom, *merge_this;
+    int64_t uid, start_tc, end_tc;
+
+    // Not every child is a chapter atomaster. Skip those.
+    atom = dynamic_cast<KaxChapterAtom *>(master[i]);
+    if (NULL == atom)
+      continue;
+
+    uid = get_chapter_uid(*atom);
+    if (-1 == uid)
+      continue;
+
+    // First get the start and end time, if present.
+    start_tc = get_chapter_start(*atom, 0);
+    end_tc = get_chapter_end(*atom);
+
+    mxverb(3, "chapters: merge_entries: looking for %lld with %lld, %lld\n",
+           uid, start_tc, end_tc);
+
+    // Now iterate over all remaining atoms and find those with the same
+    // UID.
+    k = i + 1;
+    while (true) {
+      int64_t merge_start_tc, merge_end_tc;
+
+      merge_this = NULL;
+      for (; master.ListSize() > k; ++k) {
+        KaxChapterAtom *cmp_atom;
+
+        cmp_atom = dynamic_cast<KaxChapterAtom *>(master[k]);
+        if (NULL == cmp_atom)
+          continue;
+
+        if (get_chapter_uid(*cmp_atom) == uid) {
+          merge_this = cmp_atom;
+          break;
+        }
+      }
+
+      // If we haven't found an atom with the same UID then we're done here.
+      if (NULL == merge_this)
+        break;
+
+      // Do the merger! First get the start and end timecodes if present.
+      merge_start_tc = get_chapter_start(*merge_this, 0);
+      merge_end_tc = get_chapter_end(*merge_this);
+
+      // Then compare them to the ones we have for the soon-to-be merged
+      // chapter and assign accordingly.
+      if (merge_start_tc < start_tc)
+        start_tc = merge_start_tc;
+      if ((-1 == end_tc) || (merge_end_tc > end_tc))
+        end_tc = merge_end_tc;
+
+      mxverb(3, "chapters: merge_entries:   found one at %d with %lld, %lld; "
+             "merged to %lld, %lld\n", k, merge_start_tc, merge_end_tc,
+             start_tc, end_tc);
+
+      // Finally remove the entry itself.
+      delete master[k];
+      master.Remove(k);
+    }
+
+    // Assign the start and end timecode to the chapter. Only assign an
+    // end timecode if one was present in at least one of the merged
+    // chapter atoms.
+    *static_cast<EbmlUInteger *>(&GetChild<KaxChapterTimeStart>(*atom)) =
+      start_tc;
+
+    if (-1 != end_tc)
+      *static_cast<EbmlUInteger *>(&GetChild<KaxChapterTimeEnd>(*atom)) =
+        end_tc;
+  }
+
+  // Recusively merge atoms.
+  for (i = 0; master.ListSize() > i; ++i)
+    if (NULL != dynamic_cast<EbmlMaster *>(master[i]))
+      merge_chapter_entries(*static_cast<EbmlMaster *>(master[i]));
 }
 
 /** \brief Remove all chapter atoms that are outside of a time range
@@ -670,6 +857,14 @@ remove_entries(int64_t min_tc,
    All chapter atoms that lie completely outside the timecode range
    given with <tt>[min_tc..max_tc]</tt> are deleted.
 
+   Chapters which start before the window but end inside or after the window
+   are kept as well, and their start timecode is adjusted.
+
+   If two or more chapters with the same UID are encountered on the same
+   level then those are merged into a single chapter. The start timecode
+   is the minimum start timecode of all the chapters, and the end timecode
+   is the maximum end timecode of all the chapters.
+
    The parameters are checked for validity.
 
    \param chapters The chapters to check.
