@@ -7,7 +7,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: common.cpp 2840 2005-03-01 14:52:36Z mosu $
+   $Id: common.cpp 2887 2005-04-11 10:47:01Z mosu $
 
    helper functions, common variables
 
@@ -1266,7 +1266,7 @@ mxprints(char *dst,
 static void
 mxmsg(int level,
       const char *fmt,
-      va_list &ap) {
+      va_list ap) {
   string new_fmt, output;
   bool nl;
   FILE *stream;
@@ -1397,7 +1397,15 @@ get_varg_len(const char *fmt,
   size = 1024;
   dst = (char *)safemalloc(size);
   while (1) {
+#if defined(COMP_MSC)
     result = vsnprintf(dst, size - 1, fmt, ap);
+#else
+    va_list ap2;
+
+    va_copy(ap2, ap);
+    result = vsnprintf(dst, size - 1, fmt, ap2);
+    va_end(ap2);
+#endif // defined(COMP_MSC)
     if (result >= 0) {
       safefree(dst);
       return result;
@@ -1412,16 +1420,24 @@ get_varg_len(const char *fmt,
 
 string
 mxvsprintf(const char *fmt,
-           va_list &ap) {
+           va_list ap) {
   string new_fmt, dst;
   char *new_string;
   int len;
+#if !defined(COMP_MSC)
+  va_list ap2;
+#endif
 
   fix_format(fmt, new_fmt);
   len = get_varg_len(new_fmt.c_str(), ap);
   new_string = (char *)safemalloc(len + 1);
+#if defined(COMP_MSC)
   vsprintf(new_string, new_fmt.c_str(), ap);
-  va_end(ap);
+#else
+  va_copy(ap2, ap);
+  vsprintf(new_string, new_fmt.c_str(), ap2);
+  va_end(ap2);
+#endif // defined(COMP_MSC)
   dst = new_string;
   safefree(new_string);
 
