@@ -1,27 +1,23 @@
 /*
-  mkvmerge -- utility for splicing together matroska files
-      from component media subtypes
+   mkvmerge -- utility for splicing together matroska files
+   from component media subtypes
 
-  dts_common.cpp
+   Distributed under the GPL
+   see the file COPYING for details
+   or visit http://www.gnu.org/copyleft/gpl.html
 
-  Written by Moritz Bunkus <moritz@bunkus.org>
+   $Id: dts_common.cpp 2802 2005-02-20 18:40:37Z mosu $
 
-  Distributed under the GPL
-  see the file COPYING for details
-  or visit http://www.gnu.org/copyleft/gpl.html
-*/
+   helper function for DTS data
 
-/*!
-    \file
-    \version $Id: dts_common.cpp 1434 2004-01-22 22:36:05Z mosu $
-    \brief helper function for DTS data
-    \author Peter Niemayer <niemayer@isg.de>
-    \author Moritz Bunkus <moritz@bunkus.org>
+   Written by Peter Niemayer <niemayer@isg.de>.
+   Modified by Moritz Bunkus <moritz@bunkus.org>.
 */
 
 #include <string.h>
 #include <stdio.h>
 
+#include "bit_cursor.h"
 #include "common.h"
 #include "dts_common.h"
 
@@ -65,7 +61,7 @@ static const int core_samplefreqs[16] = {
 };
 
 static const int transmission_bitrates[32] = {
-     32000,     56000,     64000,     96000,
+    32000,     56000,     64000,     96000,
    112000,    128000,    192000,    224000,
    256000,    320000,    384000,    448000,
    512000,    576000,    640000,    768000,
@@ -120,8 +116,8 @@ find_dts_header(const unsigned char *buf,
   unsigned int t;
 
   bc.get_bits(1, t);
-  dts_header->frametype = (t)? dts_header_s::frametype_normal :
-    dts_header_s::frametype_termination;
+  dts_header->frametype = (t)? dts_header_s::FRAMETYPE_NORMAL :
+    dts_header_s::FRAMETYPE_TERMINATION;
 
   bc.get_bits(5, t);
   dts_header->deficit_sample_count = (t+1) % 32;
@@ -171,14 +167,14 @@ find_dts_header(const unsigned char *buf,
 
   bc.get_bits(3, t);
   dts_header->extension_audio_descriptor =
-    (dts_header_s::extension_audio_descriptor_enum)t;
+    (dts_header_s::extension_audio_descriptor_e)t;
 
   bc.get_bit(dts_header->extended_coding);
 
   bc.get_bit(dts_header->audio_sync_word_in_sub_sub);
 
   bc.get_bits(2, t);
-  dts_header->lfe_type = (dts_header_s::lfe_type_enum)t;
+  dts_header->lfe_type = (dts_header_s::lfe_type_e)t;
 
   bc.get_bit(dts_header->predictor_history_flag);
 
@@ -189,7 +185,7 @@ find_dts_header(const unsigned char *buf,
 
   bc.get_bits(1, t);
   dts_header->multirate_interpolator =
-    (dts_header_s::multirate_interpolator_enum)t;
+    (dts_header_s::multirate_interpolator_e)t;
 
   bc.get_bits(4, t);
   dts_header->encoder_software_revision = t;
@@ -268,7 +264,7 @@ print_dts_header(const struct dts_header_s *h) {
   mxinfo("DTS Frame Header Information:\n");
 
   mxinfo("Frame Type             : ");
-  if (h->frametype == dts_header_s::frametype_normal) {
+  if (h->frametype == dts_header_s::FRAMETYPE_NORMAL) {
     mxinfo("normal");
   } else {
     mxinfo("termination, deficit sample count = %u",
@@ -287,7 +283,7 @@ print_dts_header(const struct dts_header_s *h) {
   mxinfo("Audio Channels         : %d%s, arrangement: %s\n",
          h->audio_channels, (h->source_surround_in_es)? " ES" : "" ,
          h->audio_channel_arrangement);
-  
+
   mxinfo("Core sampling frequency: %u\n", h->core_sampling_frequency);
 
   mxinfo("Transmission_bitrate   : ");
@@ -316,13 +312,13 @@ print_dts_header(const struct dts_header_s *h) {
   mxinfo("Extended Coding        : ");
   if (h->extended_coding) {
     switch (h->extension_audio_descriptor) {
-      case dts_header_s::extension_xch:
+      case dts_header_s::EXTENSION_XCH:
         mxinfo("Extra Channels");
         break;
-      case dts_header_s::extension_x96k:
+      case dts_header_s::EXTENSION_X96K:
         mxinfo("Extended frequency (x96k)");
         break;
-      case dts_header_s::extension_xch_x96k:
+      case dts_header_s::EXTENSION_XCH_X96K:
         mxinfo("Extra Channels and Extended frequency (x96k)");
         break;
       default:
@@ -338,16 +334,16 @@ print_dts_header(const struct dts_header_s *h) {
 
   mxinfo("Low Frequency Effects  : ");
   switch (h->lfe_type) {
-    case dts_header_s::lfe_none:
+    case dts_header_s::LFE_NONE:
       mxinfo("none");
       break;
-    case dts_header_s::lfe_128:
+    case dts_header_s::LFE_128:
       mxinfo("yes, interpolation factor 128");
       break;
-    case dts_header_s::lfe_64:
+    case dts_header_s::LFE_64:
       mxinfo("yes, interpolation factor 64");
       break;
-    case dts_header_s::lfe_invalid:
+    case dts_header_s::LFE_INVALID:
       mxinfo("Invalid");
       break;
   }
@@ -357,7 +353,7 @@ print_dts_header(const struct dts_header_s *h) {
          (h->predictor_history_flag)? "yes" : "no");
 
   mxinfo("Multirate Interpolator : %s\n",
-         (h->multirate_interpolator == dts_header_s::mi_non_perfect)?
+         (h->multirate_interpolator == dts_header_s::MI_NON_PERFECT)?
          "non perfect" : "perfect");
 
   mxinfo("Encoder Software Vers. : %u\n",
@@ -418,3 +414,59 @@ dts_14_to_dts_16(const unsigned short *src,
     src += 8;
   }
 }
+
+bool
+operator!=(const dts_header_t &l,
+           const dts_header_t &r) {
+  //if (l.frametype != r.frametype) return true;
+  //if (l.deficit_sample_count != r.deficit_sample_count) return true;
+  if (l.crc_present != r.crc_present)
+    return true;
+  if (l.num_pcm_sample_blocks != r.num_pcm_sample_blocks)
+    return true;
+  if (l.frame_byte_size != r.frame_byte_size)
+    return true;
+  if (l.audio_channels != r.audio_channels)
+    return true;
+  if (l.core_sampling_frequency != r.core_sampling_frequency)
+    return true;
+  if (l.transmission_bitrate != r.transmission_bitrate)
+    return true;
+  if (l.embedded_down_mix != r.embedded_down_mix)
+    return true;
+  if (l.embedded_dynamic_range != r.embedded_dynamic_range)
+    return true;
+  if (l.embedded_time_stamp != r.embedded_time_stamp)
+    return true;
+  if (l.auxiliary_data != r.auxiliary_data)
+    return true;
+  if (l.hdcd_master != r.hdcd_master)
+    return true;
+  if (l.extension_audio_descriptor != r.extension_audio_descriptor)
+    return true;
+  if (l.extended_coding != r.extended_coding)
+    return true;
+  if (l.audio_sync_word_in_sub_sub != r.audio_sync_word_in_sub_sub)
+    return true;
+  if (l.lfe_type != r.lfe_type)
+    return true;
+  if (l.predictor_history_flag != r.predictor_history_flag)
+    return true;
+  if (l.multirate_interpolator != r.multirate_interpolator)
+    return true;
+  if (l.encoder_software_revision != r.encoder_software_revision)
+    return true;
+  if (l.copy_history != r.copy_history)
+    return true;
+  if (l.source_pcm_resolution != r.source_pcm_resolution)
+    return true;
+  if (l.source_surround_in_es != r.source_surround_in_es)
+    return true;
+  if (l.front_sum_difference != r.front_sum_difference)
+    return true;
+  if (l.surround_sum_difference != r.surround_sum_difference)
+    return true;
+  if (l.dialog_normalization_gain != r.dialog_normalization_gain)
+    return true;
+  return false;
+}
