@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mm_io.cpp 2838 2005-02-28 19:26:04Z mosu $
+   $Id: mm_io.cpp 2886 2005-04-10 09:07:45Z mosu $
 
    IO callback class implementation
 
@@ -104,17 +104,12 @@ mm_file_io_c::mm_file_io_c(const string &path,
   if (use_posix_fadvise && use_posix_fadvise_here &&
       (0 != posix_fadvise(fileno((FILE *)file), 0, read_using_willneed,
                           advise))) {
-    mxwarn(FADVISE_WARNING, path.c_str(), errno, strerror(errno));
+    mxverb(2, FADVISE_WARNING, path.c_str(), errno, strerror(errno));
     use_posix_fadvise_here = false;
   }
 # endif
 }
 
-uint64
-mm_file_io_c::getFilePointer() {
-  return ftello((FILE *)file);
-}
-
 void
 mm_file_io_c::setFilePointer(int64 offset,
                              seek_mode mode) {
@@ -129,6 +124,13 @@ mm_file_io_c::setFilePointer(int64 offset,
 
   if (fseeko((FILE *)file, offset, whence) != 0)
     throw error_c("seeking failed");
+
+  if (mode == seek_beginning)
+    m_current_position = offset;
+  else if (mode == seek_end)
+    m_current_position = ftello((FILE *)file);
+  else
+    m_current_position += offset;
 }
 
 size_t
@@ -149,12 +151,14 @@ mm_file_io_c::write(const void *buffer,
     write_count = 0;
     if (0 != posix_fadvise(fileno((FILE *)file), 0, pos,
                            POSIX_FADV_DONTNEED)) {
-      mxwarn(FADVISE_WARNING, file_name.c_str(), errno, strerror(errno));
+      mxverb(2, FADVISE_WARNING, file_name.c_str(), errno, strerror(errno));
       use_posix_fadvise_here = false;
     }
   }
 # endif
 
+  m_current_position += bwritten;
+
   return bwritten;
 }
 
@@ -173,19 +177,21 @@ mm_file_io_c::read(void *buffer,
       int fd = fileno((FILE *)file);
       read_count = 0;
       if (0 != posix_fadvise(fd, 0, pos, POSIX_FADV_DONTNEED)) {
-        mxwarn(FADVISE_WARNING, file_name.c_str(), errno, strerror(errno));
+        mxverb(2, FADVISE_WARNING, file_name.c_str(), errno, strerror(errno));
         use_posix_fadvise_here = false;
       }
       if (use_posix_fadvise_here && 
           (0 != posix_fadvise(fd, pos, pos + read_using_willneed,
                               POSIX_FADV_WILLNEED))) {
-        mxwarn(FADVISE_WARNING, file_name.c_str(), errno, strerror(errno));
+        mxverb(2, FADVISE_WARNING, file_name.c_str(), errno, strerror(errno));
         use_posix_fadvise_here = false;
       }
     }
   }
 # endif
 
+  m_current_position += bread;
+
   return bread;
 }
 
@@ -288,7 +294,7 @@ mm_file_io_c::close() {
 }
 
 uint64
-mm_file_io_c::getFilePointer() {
+mm_file_io_c::get_real_file_pointer() {
   LONG high = 0;
   DWORD low;
 
@@ -302,7 +308,7 @@ mm_file_io_c::getFilePointer() {
 void
 mm_file_io_c::setFilePointer(int64 offset,
                              seek_mode mode) {
-  DWORD method;
+  DWORD method, low;
   LONG high;
 
   switch (mode) {
@@ -321,7 +327,13 @@ mm_file_io_c::setFilePointer(int64 offset,
   }
 
   high = (LONG)(offset >> 32);
-  SetFilePointer((HANDLE)file, (LONG)(offset & 0xffffffff), &high, method);
+  low = SetFilePointer((HANDLE)file, (LONG)(offset & 0xffffffff), &high,
+                       method);
+
+  if ((INVALID_SET_FILE_POINTER == low) && (GetLastError() != NO_ERROR))
+    throw error_c("seeking failed");
+
+  m_current_position = (int64_t)low + ((int64_t)high << 32);
 }
 
 uint32
@@ -331,12 +343,15 @@ mm_file_io_c::read(void *buffer,
 
   if (!ReadFile((HANDLE)file, buffer, size, &bytes_read, NULL)) {
     _eof = true;
+    m_current_position = get_real_file_pointer();
     return 0;
   }
 
   if (size != bytes_read)
     _eof = true;
 
+  m_current_position += bytes_read;
+
   return bytes_read;
 }
 
@@ -376,6 +391,8 @@ mm_file_io_c::write(const void *buffer,
       LocalFree(error_msg);
   }
 
+  m_current_position += bytes_written;
+
   return bytes_written;
 }
 
@@ -406,6 +423,11 @@ mm_file_io_c::setup() {
 
 #endif // SYS_UNIX
 
+uint64
+mm_file_io_c::getFilePointer() {
+  return m_current_position;
+}
+
 mm_file_io_c::~mm_file_io_c() {
   close();
   file_name = "";
