@@ -5,7 +5,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: xtr_base.h 2789 2005-02-11 20:38:00Z mosu $
+   $Id: xtr_base.h 2883 2005-04-07 17:31:52Z mosu $
 
    extracts tracks from Matroska files into other files
 
@@ -56,4 +56,11 @@ public:
                                       int64_t new_tid, track_spec_t &tspec);
 };
 
+class xtr_fullraw_c : public xtr_base_c {
+public:
+  xtr_fullraw_c(const string &_codec_id, int64_t _tid, track_spec_t &tspec):
+    xtr_base_c(_codec_id, _tid, tspec) {}
+  virtual void create_file(xtr_base_c *_master, KaxTrackEntry &track);
+};
+
 #endif
