@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_matroska.cpp 2827 2005-02-27 11:31:18Z mosu $
+   $Id: r_matroska.cpp 2874 2005-04-07 15:00:22Z mosu $
 
    Matroska reader
 
@@ -1130,7 +1130,7 @@ kax_reader_c::read_headers() {
                      kcodecpriv->GetSize());
             track->private_size = kcodecpriv->GetSize();
             if (track->private_size > 0)
-              track->private_data = safememdup(&binary(*kcodecpriv),
+              track->private_data = safememdup(kcodecpriv->GetBuffer(),
                                                track->private_size);
           }
 
@@ -1797,7 +1797,10 @@ kax_reader_c::read(generic_packetizer_c *,
         cluster->InitTimecode(cluster_tc, tc_scale);
         if (first_timecode == -1) {
           first_timecode = cluster_tc * tc_scale;
-          if ((chapters != NULL) && (first_timecode > 0))
+
+          // If we're appending this file to another one then the core
+          // needs the timecodes shifted to zero.
+          if (appending && (chapters != NULL) && (first_timecode > 0))
             adjust_chapter_timecodes(*chapters, -first_timecode);
         }
 
@@ -1831,9 +1834,24 @@ kax_reader_c::read(generic_packetizer_c *,
 
           block = static_cast<KaxBlock *>
             (block_group->FindFirstElt(KaxBlock::ClassInfos, false));
-          if (block != NULL) {
-            block->SetParent(*cluster);
-            block_track = find_track_by_num(block->TrackNum());
+          if (NULL == block) {
+            mxwarn(FMT_FN "A block group was found at position %lld, but "
+                   "no block element was found inside it. This might make "
+                   "mkvmerge crash.\n", ti.fname.c_str(),
+                   block_group->GetElementPosition());
+            continue;
+          }
+
+          block->SetParent(*cluster);
+          block_track = find_track_by_num(block->TrackNum());
+
+          if (NULL == block_track) {
+            mxwarn(FMT_FN "A block was found at timestamp " FMT_TIMECODE
+                   "for track number %u. However, no headers where found for "
+                   "that track number. The block will be skipped.\n",
+                   ti.fname.c_str(), ARG_TIMECODE_NS(block->GlobalTimecode()),
+                   (unsigned int)block->TrackNum());
+            continue;
           }
 
           blockadd = static_cast<KaxBlockAdditions *>
@@ -1858,6 +1876,10 @@ kax_reader_c::read(generic_packetizer_c *,
           }
 
           last_timecode = block->GlobalTimecode();
+          // If we're appending this file to another one then the core
+          // needs the timecodes shifted to zero.
+          if (appending)
+            last_timecode -= first_timecode;
 
           if ((block_track != NULL) && (block_track->ptzr != -1) &&
               block_track->passthrough) {
