@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_ogm.cpp 2809 2005-02-24 21:05:35Z mosu $
+   $Id: r_ogm.cpp 2851 2005-03-14 13:15:04Z mosu $
 
    OGG media stream reader
 
@@ -1080,10 +1080,7 @@ ogm_reader_c::handle_stream_comments() {
     return;
 
   charset_warning_printed = false;
-  if (ti.chapter_charset != "")
-    cch = utf8_init(ti.chapter_charset);
-  else
-    cch = utf8_init("");
+  cch = utf8_init(ti.chapter_charset);
 
   for (i = 0; i < sdemuxers.size(); i++) {
     dmx = sdemuxers[i];
