@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_real.cpp 2807 2005-02-24 14:19:32Z mosu $
+   $Id: r_real.cpp 2876 2005-04-07 15:17:17Z mosu $
 
    RealMedia demultiplexer module
 
@@ -326,7 +326,7 @@ real_reader_c::create_packetizer(int64_t tid) {
 
       mxprints(buffer, "V_REAL/%s", dmx->fourcc);
       dmx->ptzr =
-        add_packetizer(new video_packetizer_c(this, buffer, dmx->fps,
+        add_packetizer(new video_packetizer_c(this, buffer, 0.0,
                                               dmx->width, dmx->height, ti));
       if ((dmx->fourcc[0] != 'R') || (dmx->fourcc[1] != 'V') ||
           (dmx->fourcc[2] != '4') || (dmx->fourcc[3] != '0'))
