@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: cluster_helper.cpp 2807 2005-02-24 14:19:32Z mosu $
+   $Id: cluster_helper.cpp 2860 2005-03-19 11:54:26Z mosu $
 
    The cluster helper groups frames into blocks groups and those
    into clusters, sets the durations, renders the clusters etc.
@@ -163,7 +163,8 @@ cluster_helper_c::add_packet(packet_t *packet) {
       if ((header_overhead + additional_size + bytes_in_file) >= split_after)
         split = true;
 
-    } else if ((packet->assigned_timecode - first_timecode_in_file) >=
+    } else if ((0 <= first_timecode_in_file) && 
+               (packet->assigned_timecode - first_timecode_in_file) >=
                (split_after * 1000000ull))
       split = true;
 
