@@ -8,7 +8,7 @@
    or visit http://www.gnu.org/copyleft/gpl.html
 
    \file
-   \version $Id: output_control.cpp 2844 2005-03-06 14:28:26Z mosu $
+   \version $Id: output_control.cpp 2872 2005-04-07 08:46:58Z mosu $
 
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
    \author Modified by Steve Lhomme <steve.lhomme@free.fr>.
@@ -636,7 +636,8 @@ render_headers(mm_io_c *rout) {
       for (i = 0; i < packetizers.size(); i++)
         if (packetizers[i].packetizer != NULL)
           packetizers[i].packetizer->fix_headers();
-    }
+    } else
+      set_timecode_scale();
 
     kax_infos->Render(*rout, true);
     kax_sh_main->IndexThis(*kax_infos, *kax_segment);
@@ -1512,7 +1513,9 @@ finish_file(bool last_file) {
     if (splitting)
       chapters_here = select_chapters_in_timeframe(chapters_here, start, end,
                                                    offset);
+
     if (chapters_here != NULL) {
+      merge_chapter_entries(*chapters_here);
       sort_ebml_master(chapters_here);
       kax_chapters_void->ReplaceWith(*chapters_here, *out, true, true);
       chapters_in_this_file =
@@ -1626,6 +1629,10 @@ append_track(packetizer_t &ptzr,
   generic_packetizer_c *old_packetizer;
   int64_t timecode_adjustment;
 
+  if (NULL != deferred_file)
+    src_file.deferred_max_timecode_seen =
+      deferred_file->reader->max_timecode_seen;      
+
   // Find the generic_packetizer_c that we will be appending to the one
   // stored in ptzr.
   foreach(gptzr, src_file.reader->reader_packetizers)
@@ -1647,9 +1654,11 @@ append_track(packetizer_t &ptzr,
     establish_deferred_connections(dst_file);
   }
 
-  if (((*gptzr)->get_track_type() == track_subtitle) &&
-      (dst_file.reader->num_video_tracks == 0) &&
-      (video_packetizer != NULL) && !ptzr.deferred) {
+  if ((track_subtitle == (*gptzr)->get_track_type()) &&
+      (0 == dst_file.reader->num_video_tracks) &&
+      (NULL != video_packetizer) &&
+      !ptzr.deferred &&
+      (-1 == src_file.deferred_max_timecode_seen)) {
     vector<filelist_t>::iterator file;
 
     foreach(file, files) {
@@ -1710,9 +1719,14 @@ append_track(packetizer_t &ptzr,
   // files if they've been split before.
   timecode_adjustment = dst_file.reader->max_timecode_seen;
   if (ptzr.deferred && (deferred_file != NULL))
-    timecode_adjustment = deferred_file->reader->max_timecode_seen;
+    timecode_adjustment = src_file.deferred_max_timecode_seen;
+
+  else if ((track_subtitle == ptzr.packetizer->get_track_type()) &&
+           (-1 < src_file.deferred_max_timecode_seen))
+    timecode_adjustment = src_file.deferred_max_timecode_seen;
+
   else if ((ptzr.packetizer->get_track_type() == track_subtitle) ||
-             (src_file.reader->chapters != NULL)) {
+           (src_file.reader->chapters != NULL)) {
     vector<append_spec_t>::const_iterator cmp_amap;
 
     if (src_file.reader->ptzr_first_packet == NULL)
