@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: pr_generic.cpp 2844 2005-03-06 14:28:26Z mosu $
+   $Id: pr_generic.cpp 2888 2005-04-16 10:53:18Z mosu $
 
    functions common for all readers/packetizers
 
@@ -50,7 +50,8 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *nreader,
   reader = nreader;
 
   track_entry = NULL;
-  free_refs = -1;
+  m_free_refs = -1;
+  m_next_free_refs = -1;
   enqueued_bytes = 0;
   safety_last_timecode = 0;
   safety_last_duration = 0;
@@ -235,7 +236,8 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *nreader,
   }
 
   // Set default header values to 'unset'.
-  hserialno = create_track_number(reader, ti.id);
+  if (!reader->appending)
+    hserialno = create_track_number(reader, ti.id);
   huid = 0;
   htrack_type = -1;
   htrack_min_cache = 0;
@@ -1072,7 +1074,8 @@ generic_packetizer_c::handle_avi_audio_sync(int64_t num_bytes,
 void
 generic_packetizer_c::connect(generic_packetizer_c *src,
                               int64_t _append_timecode_offset) {
-  free_refs = src->free_refs;
+  m_free_refs = src->m_free_refs;
+  m_next_free_refs = src->m_next_free_refs;
   track_entry = src->track_entry;
   hserialno = src->hserialno;
   htrack_type = src->htrack_type;
