@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: tab_attachments.cpp 2711 2005-01-12 15:03:47Z mosu $
+   $Id: tab_attachments.cpp 2829 2005-02-27 16:50:04Z mosu $
 
    "attachments" tab
 
@@ -140,11 +140,16 @@ tab_attachments::enable(bool e) {
 void
 tab_attachments::on_add_attachment(wxCommandEvent &evt) {
   wxFileDialog dlg(NULL, wxT("Choose an attachment file"), last_open_dir,
-                   wxT(""), wxT(ALLFILES), wxOPEN);
+                   wxT(""), wxT(ALLFILES), wxOPEN | wxMULTIPLE);
 
   if(dlg.ShowModal() == wxID_OK) {
+    wxArrayString files;
+    int i;
+
     last_open_dir = dlg.GetDirectory();
-    add_attachment(dlg.GetPath());
+    dlg.GetPaths(files);
+    for (i = 0; i < files.Count(); i++)
+      add_attachment(files[i]);
   }
 }
 
