@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: tab_global.h 2711 2005-01-12 15:03:47Z mosu $
+   $Id: tab_global.h 2822 2005-02-26 22:44:59Z mosu $
 
    declarations for the global tab
 
@@ -58,7 +58,8 @@ public:
   void on_browse_chapters(wxCommandEvent &evt);
   void on_browse_global_tags(wxCommandEvent &evt);
   void on_split_clicked(wxCommandEvent &evt);
-  void on_splitby_clicked(wxCommandEvent &evt);
+  void on_splitby_size_clicked(wxCommandEvent &evt);
+  void on_splitby_time_clicked(wxCommandEvent &evt);
 
   void save(wxConfigBase *cfg);
   void load(wxConfigBase *cfg);
