@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: tab_input.cpp 2849 2005-03-13 17:47:27Z mosu $
+   $Id: tab_input.cpp 2858 2005-03-19 11:02:04Z mosu $
 
    "input" tab
 
@@ -314,6 +314,7 @@ tab_input::tab_input(wxWindow *parent):
   cob_fourcc->Append(wxT("DIVX"));
   cob_fourcc->Append(wxT("DIV3"));
   cob_fourcc->Append(wxT("DX50"));
+  cob_fourcc->Append(wxT("MP4V"));
   cob_fourcc->Append(wxT("XVID"));
   cob_fourcc->SetToolTip(TIP("Forces the FourCC of the video track to this "
                              "value. Note that this only works for video "
@@ -1693,7 +1694,6 @@ tab_input::load(wxConfigBase *cfg) {
                   "Moritz Bunkus <moritz@bunkus.org>\n\n"
                   "(Problem occured in tab_input::load(), #3)"));
       mmg_track_ptr &t = files[fidx].tracks[tidx];
-      t->enabled = true;
       tracks.push_back(t.get());
 
       fix_format("%s%s (ID %lld, type: %s) from %s", format);
@@ -1707,7 +1707,7 @@ tab_input::load(wxConfigBase *cfg) {
                    t->type == 's' ? wxT("subtitles") : wxT("unknown"),
                    name.c_str());
       clb_tracks->Append(label);
-      clb_tracks->Check(i, true);
+      clb_tracks->Check(i, t->enabled);
     }
   }
   st_tracks->Enable(tracks.size() > 0);
