@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_passthrough.cpp 2809 2005-02-24 21:05:35Z mosu $
+   $Id: p_passthrough.cpp 2842 2005-03-02 15:53:34Z mosu $
 
    PASSTHROUGH output module
 
@@ -102,12 +102,13 @@ passthrough_packetizer_c::dump_debug_info() {
 }
 
 connection_result_e
-passthrough_packetizer_c::can_connect_to(generic_packetizer_c *src) {
+passthrough_packetizer_c::can_connect_to(generic_packetizer_c *src,
+                                         string &error_message) {
   passthrough_packetizer_c *psrc;
 
   psrc = dynamic_cast<passthrough_packetizer_c *>(src);
   if (psrc == NULL)
     return CAN_CONNECT_NO_FORMAT;
-  // For now...
+  connect_check_codec_id(hcodec_id, psrc->hcodec_id);
   return CAN_CONNECT_NO_PARAMETERS;
 }
