@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_video.cpp 2845 2005-03-06 14:30:23Z mosu $
+   $Id: p_video.cpp 2857 2005-03-19 10:55:12Z mosu $
 
    video output module
 
@@ -61,9 +61,11 @@ video_packetizer_c::check_fourcc() {
   if ((hcodec_id == MKV_V_MSCOMP) &&
       (ti.private_data != NULL) &&
       (ti.private_size >= sizeof(alBITMAPINFOHEADER)) &&
-      (ti.fourcc[0] != 0))
+      (ti.fourcc[0] != 0)) {
     memcpy(&((alBITMAPINFOHEADER *)ti.private_data)->bi_compression,
            ti.fourcc, 4);
+    set_codec_private(ti.private_data, ti.private_size);
+  }
 }
 
 void
